# Installation
**Windows (7 and above):**
- Install the latest version of [Python](https://www.python.org/downloads/) (3.6 and above)
- On the front page of the installer, check **Add Python to PATH**
- Click on **Install Now**. If you choose *Customize installation*, leave *pip* checked
- Download and execute the [install script for Windows](https://gitlab.com/william.belanger/qtlab/raw/master/exe/install.exe?inline=false)

**Linux (Arch):**
- Install 'qtlab-git' from the AUR

**Linux (Debian):**
```
sudo apt-get update
sudo apt-get install python3 python3-pip python3-setuptools
sudo pip3 install qtlab
```
